"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.OtpSenderService = void 0;
const tslib_1 = require("tslib");
const context_1 = require("@loopback/context");
const core_1 = require("@loopback/core");
const repository_1 = require("@loopback/repository");
const rest_1 = require("@loopback/rest");
const core_2 = require("@sourceloop/core");
const providers_1 = require("../providers");
const repositories_1 = require("../repositories");
let OtpSenderService = class OtpSenderService {
    constructor(otpCacheRepo, userRepository, logger, otpSender, response) {
        this.otpCacheRepo = otpCacheRepo;
        this.userRepository = userRepository;
        this.logger = logger;
        this.otpSender = otpSender;
        this.response = response;
    }
    async sendOtp(client, username) {
        if (!client) {
            this.logger.error('Auth client not found or invalid');
            throw new rest_1.HttpErrors.Unauthorized("Client Invalid" /* ClientInvalid */);
        }
        const res = await this.otpSender(username);
        await this.otpCacheRepo.delete(username);
        await this.otpCacheRepo.set(username, {
            otpSecret: res.key,
            clientId: client.clientId,
            clientSecret: client.secret,
        });
        if (res.qrCode) {
            this.response.send({
                qrCode: res.qrCode,
            });
        }
    }
};
OtpSenderService = tslib_1.__decorate([
    (0, core_1.injectable)({ scope: core_1.BindingScope.TRANSIENT }),
    tslib_1.__param(0, (0, repository_1.repository)(repositories_1.OtpCacheRepository)),
    tslib_1.__param(1, (0, repository_1.repository)(repositories_1.UserRepository)),
    tslib_1.__param(2, (0, context_1.inject)(core_2.LOGGER.LOGGER_INJECT)),
    tslib_1.__param(3, (0, context_1.inject)(providers_1.VerifyBindings.OTP_PROVIDER)),
    tslib_1.__param(4, (0, context_1.inject)(rest_1.RestBindings.Http.RESPONSE)),
    tslib_1.__metadata("design:paramtypes", [repositories_1.OtpCacheRepository,
        repositories_1.UserRepository, Object, Function, Object])
], OtpSenderService);
exports.OtpSenderService = OtpSenderService;
//# sourceMappingURL=otp-sender.service.js.map